@@ -1,4 +1,4 @@
-# This code is part of Perl distribution Mail-Message version 3.021.
+# This code is part of Perl distribution Mail-Message version 3.022.
 # The POD got stripped from this file by OODoc version 3.06.
 # For contributors see file ChangeLog.
 
@@ -10,7 +10,7 @@
 
 
 package Mail::Message::Field;{
-our $VERSION = '3.021';
+our $VERSION = '3.022';
 }
 
 use base 'Mail::Reporter';
@@ -19,9 +19,10 @@ use strict;
 use warnings;
 
 use Carp;
-use Mail::Address    ();
-use IO::Handle       ();
-use Date::Format     qw/strftime/;
+use Mail::Address        ();
+use IO::Handle           ();
+use Date::Format         qw/strftime/;
+use Hash::Case::Preserve ();
 
 our %_structured;  # not to be used directly: call isStructured!
 my $default_wrap_length = 78;
@@ -201,7 +202,7 @@ sub attribute($;$)
 	# broken messages do repeat them.  See github issue 20.  Apple Mail and
 	# Outlook will take the last of the repeated in such case, so we do that
 	# as well.
-	my %attrs = $self->attributes;
+	tie my %attrs, 'Hash::Case::Preserve', [ $self->attributes ];
 	@_ or return $attrs{$attr};
 
 	# set the value
